collective.collectionfilter
===========================

Less Compilation
----------------

To udpate/generate css from less, use the following snippet


  ::

   lessc --source-map=collectionfilter-compiled.css.map collectionfilter.less collectionfilter-compiled.css


or use plone-compile-resources
